/* _dict.cc 04/07/1998 17.43.04 */
/* motd.cc 28/08/2000 18.13.46 */
PUBLIC MODULE_motd::MODULE_motd (void);
PUBLIC void MODULE_motd::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_motd::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_motd::dohtml (const char *key);
PUBLIC int MODULE_motd::execmain (int argc, char *argv[], bool);
